diff --git a/android/app/src/main/AndroidManifest.xml b/android/app/src/main/AndroidManifest.xml
index f329b63..22821f5 100644
--- a/android/app/src/main/AndroidManifest.xml
+++ b/android/app/src/main/AndroidManifest.xml
@@ -27,7 +27,7 @@
+ android:value="ca-app-pub-5605900229781491~8257495040"/>
UIApplicationSupportsIndirectInputEvents
GADApplicationIdentifier
- ca-app-pub-3940256099942544~1458002511
+ ca-app-pub-5605900229781491~8397095848
NSUserTrackingUsageDescription
We use this to show ads that are more relevant to you. You can play fully either way.
SKAdNetworkItems
diff --git a/lib/services/ad_config.dart b/lib/services/ad_config.dart
index 681ba10..ba20e59 100644
--- a/lib/services/ad_config.dart
+++ b/lib/services/ad_config.dart
@@ -27,13 +27,15 @@ class AdConfig {
static const _testBannerAndroid = 'ca-app-pub-3940256099942544/6300978111';
static const _testBannerIos = 'ca-app-pub-3940256099942544/2934735716';
- // --- Owner replaces these with real AdMob console unit IDs ---
- static const _realInterstitialAndroid = 'TODO_REAL_INTERSTITIAL_ANDROID';
- static const _realInterstitialIos = 'TODO_REAL_INTERSTITIAL_IOS';
- static const _realRewardedAndroid = 'TODO_REAL_REWARDED_ANDROID';
- static const _realRewardedIos = 'TODO_REAL_REWARDED_IOS';
- static const _realBannerAndroid = 'TODO_REAL_BANNER_ANDROID';
- static const _realBannerIos = 'TODO_REAL_BANNER_IOS';
+ // --- Real AdMob console unit IDs (publisher pub-5605900229781491) ---
+ static const _realInterstitialAndroid =
+ 'ca-app-pub-5605900229781491/8489470891';
+ static const _realInterstitialIos =
+ 'ca-app-pub-5605900229781491/2953197478';
+ static const _realRewardedAndroid = 'ca-app-pub-5605900229781491/4478032132';
+ static const _realRewardedIos = 'ca-app-pub-5605900229781491/7011566835';
+ static const _realBannerAndroid = 'ca-app-pub-5605900229781491/5072970060';
+ static const _realBannerIos = 'ca-app-pub-5605900229781491/3620287592';
static String _pick(String testA, String testI, String realA, String realI) {
final android = useTestIds ? testA : realA;